"""
Create DataFrame string representations that can be used to create new DataFrames.
"""


from ._pdrepr import pdrepr


__all__ = [pdrepr]
